@@ -37,8 +37,8 @@ def to_bdd(circ_or_expr, output=None, manager=None, renamer=None, levels=None):
 
     manager.declare(*input_refs_to_var.values())
     if levels is not None:
-        assert set(manager.vars) <= set(levels.keys())
-        levels = fn.project(levels, manager.vars.keys())
+        assert set(manager.vars) <= set(levels)
+        levels = fn.project(levels, set(manager.vars))
         levels = fn.walk_keys(input_refs_to_var.get, levels)
 
         manager.reorder(levels)
